import numpy as np
import matplotlib.pyplot as plt
import seaborn as sb
import scipy.stats as ss
import pystan
import pickle

#
#           データの読み込み
#
flnm = input('Data file name(*.csv) = ')
fin = open(flnm, 'r')
data = fin.readlines()
fin.close()

N = len(data) - 1
DataID = []
RTs = []
for i in range(N):
    str = data[i+1].split(',')
    DataID.append(str[0])
    RTs.append(float(str[1]))

for i in range(N):
    print(DataID[i],'  ', RTs[i])

RTs = np.array(RTs)

sm = pystan.StanModel(file = 'Ex_Gaussian.stan')

Data = {'N': N, 'RT': RTs}
fit = sm.sampling(data = Data, n_jobs = 1)

print(fit)

mu = fit['mu']
sgm = fit['sgm']
lmd = fit['lmd']

plt.hist(mu)
plt.title('Posterior Distribution of $\mu$', fontsize = 16)
plt.xlabel('$\mu$', fontsize = 14)
plt.show()

plt.hist(sgm)
plt.title('Posterior Distribution of $\sigma$', fontsize = 16)
plt.xlabel('$\sigma$', fontsize = 14)
plt.show()

plt.hist(lmd)
plt.title('Posterior Distribution of $\lambda$', fontsize = 16)
plt.xlabel('$\lambda$', fontsize = 14)
plt.show()

mu_med = np.percentile(mu, 50)
sgm_med = np.percentile(sgm, 50)
lmd_med = np.percentile(lmd, 50)
K = 1.0 / (sgm_med * lmd_med)
x_min = RTs.min() - (RTs.max() - RTs.min()) * 0.1
x_max = RTs.max() + (RTs.max() - RTs.min()) * 0.1
x = np.arange(x_min, x_max, (x_max - x_min) / 100)
RT_crv = ss.exponnorm.pdf(x, K, mu_med, sgm_med)
plt.plot(x, RT_crv, linewidth = 3, label = 'Ex-Gaussian')
plt.title('ex-Gaussian($\mu$,$\sigma$,$\lambda$)\n' +\
          '$\mu$ = {0:<.3f}  $\sigma$ = {1:<.5f}  $\lambda$ = {2:<.3f}'.
          format(mu_med, sgm_med, lmd_med), fontsize = 16)
plt.hist(RTs, density = True, label = 'RT')
plt.xlabel('Time', fontsize = 14)
plt.legend()
plt.show()


